instrumenttools.BassTrombone
============================

.. abjad-lineage:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone

.. autoclass:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.BassTrombone.BassTrombone.BassTrombone.__repr__
   :noindex:
